summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorgdr <gdr@138bc75d-0d04-0410-961f-82ee72b054a4>2000-03-12 19:03:13 +0000
committergdr <gdr@138bc75d-0d04-0410-961f-82ee72b054a4>2000-03-12 19:03:13 +0000
commitba1acc74b3aec6098e9a3d9042f116d13f26c986 (patch)
treeae435b6bdc1516e5d286132aff49c1aceb2a3074
parent3467e46177b0c62ff6506a5aa547968515835c2d (diff)
downloadgcc-ba1acc74b3aec6098e9a3d9042f116d13f26c986.tar.gz
Revert previous checkin
git-svn-id: svn+ssh://gcc.gnu.org/svn/gcc/trunk@32495 138bc75d-0d04-0410-961f-82ee72b054a4
-rw-r--r--gcc/cp/parse.c11
1 files changed, 5 insertions, 6 deletions
diff --git a/gcc/cp/parse.c b/gcc/cp/parse.c
index 4e5d05b69f8..2d5610d6a5e 100644
--- a/gcc/cp/parse.c
+++ b/gcc/cp/parse.c
@@ -1,7 +1,6 @@
/* A Bison parser, made from parse.y
- by GNU Bison version 1.27
- */
+ by GNU Bison version 1.28 */
#define YYBISON 1 /* Identify Bison output. */
@@ -4031,8 +4030,8 @@ static const short yycheck[] = { 4,
78, 79, 80, 81, 82, 83, 84, 85
};
/* -*-C-*- Note some compilers choke on comments on `#line' lines. */
#line 3 "/BASE/dosreis/share/bison.simple"
/* This file comes from bison-1.27. */
/* Skeleton output parser for bison,
Copyright (C) 1984, 1989, 1990 Free Software Foundation, Inc.
@@ -4245,7 +4244,7 @@ __yy_memcpy (char *to, char *from, unsigned int count)
#endif
#endif
-#line 216 "/BASE/dosreis/share/bison.simple"
+#line 217 "/usr/lib/bison.simple"
/* The user can define YYPARSE_PARAM as the name of an argument to be passed
into yyparse. The argument should have type void *.
@@ -8230,7 +8229,7 @@ case 878:
break;}
}
/* the action file gets copied in in place of this dollarsign */
-#line 542 "/BASE/dosreis/share/bison.simple"
+#line 543 "/usr/lib/bison.simple"
yyvsp -= yylen;
yyssp -= yylen;
@@ -4031,8 +4030,8 @@ static const short yycheck[] = { 4,
};
/* -*-C-*- Note some compilers choke on comments on `#line' lines. */
-#line 3 "/BASE/dosreis/share/bison.simple"
-/* This file comes from bison-1.27. */
+#line 3 "/usr/lib/bison.simple"
+/* This file comes from bison-1.28. */
/* Skeleton output parser for bison,
Copyright (C) 1984, 1989, 1990 Free Software Foundation, Inc.